# FiMDPEnv

**Simulation environments for FiMDP**

**FiMDPEnv** is a Python package with realistic simulation environments for testing and benchmarking the tools in the [FiMDP](https://github.com/xblahoud/FiMDP) package. The package provides consumption Markov Decision Processes (CMDPs) modeling different real-world problems along with tools to analyze, manipulate, and visualize the CMDP and any strategies generated by the FiMDP package.

### Contact
If you have any trouble with the installation, or have any questions, raise an issue or email [Pranay Thangeda](contact@prny.me).
